@@ -73,8 +73,10 @@ move = "move"/Struct(
     "selected"/Int32ul,
     "x"/Float32l,
     "y"/Float32l,
-    "next"/Peek(Bytes(8)),
-    "flags"/If(lambda ctx: check_flags(ctx.next), Bytes(8)),
+    If(lambda ctx: ctx.selected < 0xff, Struct(
+        "next"/Peek(Bytes(8)),
+        "flags"/If(lambda ctx: check_flags(ctx.next), Bytes(8))
+    )),
     "unit_ids"/If(lambda ctx: ctx.selected < 0xff, Array(
         lambda ctx: ctx.selected, Int32ul
     ))
@@ -410,7 +412,8 @@ order = "order"/Struct(
     Padding(2),
     "building_id"/Int32sl, # -1 cancels production queue
     OrderTypeEnum("order_type"/Byte),
-    Padding(3),
+    "cancel_order"/Byte, # when cancelling production queue, this indicates which item in the queue is to be cancelled
+    Padding(2),
     "x"/Float32l,
     "y"/Float32l,
     Padding(4), # const
